==> nextcloud-app-tasks-0.16.1-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/pt_PT.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Próximas tarefas",
    "Important" : "Importante",
    "Today" : "Hoje",
    "Week" : "Semana",
    "All" : "Todas",
    "Current" : "Actual",
    "Completed" : "Concluída",
    "Tasks" : "Tarefas",
    "The Tasks app for Nextcloud" : "A aplicação Tarefas para Nextcloud",
    "Visibility of Smart Collections" : "Visibilidade das Coleções Inteligentes",
    "Hidden" : "Escondido",
    "Visible" : "Visível",
    "Automatic" : "Automático",
    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
    "No users or groups" : "Sem utilizadores ou grupos",
    "Can edit" : "Pode editar",
    "Unshare with {displayName}" : "Cancelar partilha com {displayName}",
    "Unable to delete the share." : "Não foi possível eliminar a partilha de rede.",
    "Unable to change permissions." : "Não é possível alterar as permissões.",
    "Edit" : "Editar",
    "Copy private link" : "Copiar link privado",
    "Copied" : "Copiado",
    "Cannot copy" : "Não é possível copiar",
    "Export" : "Exportar",
    "Delete" : "Eliminar ",
    "Unshare" : "Cancelar partilha",
    "Calendar link copied to clipboard." : "Link do calendário copiado para a área de transferência.",
    "Calendar link could not be copied to clipboard." : "Link do calendário não pôde se copiado para a área de transferência.",
    "An empty name is not allowed." : "Não é permitido um nome em branco.",
    "An error occurred, unable to delete the calendar." : "Ocorreu um erro que impede que o calendário seja apagado",
    "Trash bin" : "Reciclagem",
    "Name" : "Nome",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Eliminar permanentemente",
    "Empty trash bin" : "Esvaziar a reciclagem",
    "Untitled item" : "Item sem título ",
    "Unknown calendar" : "Calendário desconhecido",
    "Could not load deleted calendars and objects" : "Não foi possível carregar calendários e objetos apagados ",
    "Could not restore calendar or event" : "Não foi possível restaurar o calendário ou evento ",
    "Do you really want to empty the trash bin?" : "Tem a certeza que pretende esvaziar a reciclagem?",
    "Cancel" : "Cancelar",
    "Close" : "Fechar",
    "No errors" : "Sem erros",
    "Open your browser console for more details" : "Abra a consola do seu navegador para obter mais detalhes",
    "Select tags to filter by" : "Selecionar etiquetas para filtrar",
    "Change sort order" : "Alterar ordenação",
    "Start date" : "Data de início",
    "Due date" : "Data limite",
    "Last modified" : "Última modificação",
    "Priority" : "Prioridade",
    "Alphabetically" : "Alfabeticamente",
    "Manually" : "Manual",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarefa Concluída","%n Tarefas Concluídas","%n Tarefas Concluídas"],
    "Tomorrow" : "Amanhã",
    "All day" : "Todo o dia",
    "Details" : "Detalhes",
    "Notes" : "Notas",
    "Reminders" : "Lembretes",
    "Repeat" : "Repetir",
    "When shared show full event" : "Quando partilhado, mostrar evento completo",
    "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
    "When shared hide this event" : "Quando partilhado, ocultar este evento",
    "Canceled" : "Cancelado",
    "Task not found!" : "Tarefa não encontrada!",
    "Set start date" : "Defina a data de inicio ",
    "Set due date" : "Definir data de expiração",
    "An error occurred" : "Ocorreu um erro"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-tasks-0.17.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/pt_PT.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Próximas tarefas",
    "Important" : "Importante",
    "Today" : "Hoje",
    "Week" : "Semana",
    "All" : "Todas",
    "Current" : "Atual",
    "Completed" : "Concluída",
    "Tasks" : "Tarefas",
    "The Tasks app for Nextcloud" : "A aplicação Tarefas para Nextcloud",
    "Hidden" : "Escondido",
    "Visible" : "Visível",
    "Automatic" : "Automático",
    "Visibility of Smart Collections" : "Visibilidade das Coleções Inteligentes",
    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
    "No users or groups" : "Sem utilizadores ou grupos",
    "Unable to delete the share." : "Não foi possível eliminar a partilha de rede.",
    "Unable to change permissions." : "Não é possível alterar as permissões.",
    "Can edit" : "Pode editar",
    "Unshare with {displayName}" : "Cancelar partilha com {displayName}",
    "Calendar link copied to clipboard." : "Link do calendário copiado para a área de transferência.",
    "Calendar link could not be copied to clipboard." : "Link do calendário não pôde se copiado para a área de transferência.",
    "An empty name is not allowed." : "Não é permitido um nome em branco.",
    "An error occurred, unable to delete the calendar." : "Ocorreu um erro que impede que o calendário seja apagado",
    "Edit" : "Editar",
    "Copy private link" : "Copiar link privado",
    "Copied" : "Copiado",
    "Cannot copy" : "Não é possível copiar",
    "Export" : "Exportar",
    "Delete" : "Eliminar ",
    "Unshare" : "Cancelar partilha",
    "Untitled task" : "Untitled task",
    "Untitled event" : "Evento sem título",
    "Untitled item" : "Item sem título ",
    "Unknown calendar" : "Calendário desconhecido",
    "Could not load deleted calendars and objects" : "Não foi possível carregar calendários e objetos apagados ",
    "Could not restore calendar or event" : "Não foi possível restaurar o calendário ou evento ",
    "Do you really want to empty the trash bin?" : "Tem a certeza que pretende esvaziar a reciclagem?",
    "Empty trash bin" : "Esvaziar a reciclagem",
    "Trash bin" : "Reciclagem",
    "Name" : "Nome",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Eliminar permanentemente",
    "Cancel" : "Cancelar",
    "Email" : "E-mail",
    "Audio notification" : "Notificação de áudio",
    "Other notification" : "Outras notificações",
    "Edit time" : "Editar horário",
    "Remove reminder" : "Apagar lembrete",
    "Add reminder" : "Adicionar lembrete ",
    "Go back" : "Voltar",
    "before at" : "antes em",
    "_second_::_seconds_" : ["segundo","segundos","segundos"],
    "_minute_::_minutes_" : ["minuto","minutos","minutos"],
    "_hour_::_hours_" : ["hora","horas","horas"],
    "_day_::_days_" : ["dia","dias","dias"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "Close" : "Fechar",
    "No errors" : "Sem erros",
    "Open your browser console for more details" : "Abra a consola do seu navegador para obter mais detalhes",
    "Select tags to filter by" : "Selecionar etiquetas para filtrar",
    "Start date" : "Data de início",
    "Due date" : "Data limite",
    "Last modified" : "Última modificação",
    "Priority" : "Prioridade",
    "Alphabetically" : "Alfabeticamente",
    "Tags" : "Etiquetas",
    "Manually" : "Manual",
    "Change sort order" : "Alterar ordenação",
    "Delete task" : "Eliminar tarefa",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarefa Concluída","%n Tarefas Concluídas","%n Tarefas Concluídas"],
    "Tomorrow" : "Amanhã",
    "When shared show full event" : "Quando partilhado, mostrar evento completo",
    "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
    "When shared hide this event" : "Quando partilhado, ocultar este evento",
    "Canceled" : "Cancelado",
    "Task not found!" : "Tarefa não encontrada!",
    "Set start date" : "Defina a data de inicio ",
    "Set due date" : "Definir data de expiração",
    "All day" : "Todo o dia",
    "Details" : "Detalhes",
    "Notes" : "Notas",
    "An error occurred" : "Ocorreu um erro"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
